#include <linux/version.h>
#include <endian.h>

#ifdef __alpha__
# include "osdep-alpha.h"
#endif

#ifdef __i386__
# include "osdep-i386.h"
#endif

#ifdef __powerpc__
# include "osdep-ppc.h"
#endif

#ifdef __arm__
# include "osdep-arm.h"
#endif

#if defined(__GLIBC__) && __GLIBC__ >= 2
# include <netinet/if_ether.h>
#else
# include <linux/if_ether.h>
#endif

#if 0 /* 1999/06/30 */
#if LINUX_VERSION_CODE >= 0x020200
#include <sys/socket.h>
#include <linux/netlink.h>
#endif
#endif

#ifndef NETLINK_TAPBASE
#define NETLINK_TAPBASE 16
#endif
